throw new Error("Explicitly forcing the JS test to fail.");
